@@ -32,8 +32,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: pycomp.py 295 2007-07-15 02:37:25Z CodyPrecord $"
-__revision__ = "$Revision: 295 $"
+__cvsid__ = "$Id: pycomp.py 342 2007-08-13 18:41:00Z CodyPrecord $"
+__revision__ = "$Revision: 342 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -234,7 +234,7 @@ class Completer(object):
                 return False
             try:
                 exec code in newspace
-            except (ImportError, RuntimeError, SyntaxError, SystemError):
+            except Exception:
                 return False
             else:
                 # No problems, so update the namespace.
