@@ -24,8 +24,8 @@
 
 """
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: dev_tool.py 318 2007-07-23 09:42:33Z CodyPrecord $"
-__revision__ = "$Revision: 318 $"
+__svnid__ = "$Id: dev_tool.py 344 2007-08-13 21:46:37Z CodyPrecord $"
+__revision__ = "$Revision: 344 $"
 
 import os
 import sys
@@ -130,6 +130,8 @@ def ExceptionHook(exctype, value, trace):
 
     """
     ftrace = FormatTrace(exctype, value, trace)
+    # Ensure that error gets raised to console as well
+    print ftrace
     ErrorDialog(ftrace)
 
 def FormatTrace(etype, value, trace):
