@@ -35,8 +35,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: ed_art.py 310 2007-07-22 02:29:01Z CodyPrecord $"
-__revision__ = "$Revision: 310 $"
+__cvsid__ = "$Id: ed_art.py 333 2007-08-04 01:16:32Z CodyPrecord $"
+__revision__ = "$Revision: 333 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -58,6 +58,7 @@ ART = { ed_glob.ID_ABOUT  : u'about.png',
         ed_glob.ID_COPY   : u'copy.png',
         ed_glob.ID_COMPUTER : u'computer.png',
         ed_glob.ID_CUT    : u'cut.png',
+        ed_glob.ID_DELETE : u'delete.png',
         ed_glob.ID_EXIT   : u'quit.png',
         ed_glob.ID_FILE   : u'file.png',
         ed_glob.ID_FIND   : u'find.png',
@@ -132,6 +133,7 @@ DEFAULT = {
             ed_glob.ID_CDROM   : wx.ART_CDROM,
             ed_glob.ID_COPY    : wx.ART_COPY,
             ed_glob.ID_CUT     : wx.ART_CUT,
+            ed_glob.ID_DELETE  : wx.ART_DELETE,
             ed_glob.ID_DEL_BM  : wx.ART_DEL_BOOKMARK,
             ed_glob.ID_EXIT    : wx.ART_QUIT,
             ed_glob.ID_FILE    : wx.ART_NORMAL_FILE,
