@@ -37,8 +37,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: ed_cmdbar.py 267 2007-07-07 10:38:04Z CodyPrecord $"
-__revision__ = "$Revision: 267 $"
+__cvsid__ = "$Id: ed_cmdbar.py 341 2007-08-07 23:34:03Z CodyPrecord $"
+__revision__ = "$Revision: 341 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -132,9 +132,11 @@ class CommandBar(wx.Panel):
         # Install Controls
         v_sizer = wx.BoxSizer(wx.VERTICAL)
         self._h_sizer.Add((8, 8))
+        bstyle = wx.BU_EXACTFIT
+        if wx.Platform == '__WXGTK__':
+            bstyle = bstyle | wx.NO_BORDER
         self.close_b = wx.BitmapButton(self, ID_CLOSE_BUTTON, GetXBitmap(), \
-                                      size=(14, 14), style=wx.BU_AUTODRAW | \
-                                                           wx.BU_EXACTFIT)
+                                      size=(14, 14), style=bstyle)
         self._h_sizer.Add(self.close_b, 0, wx.ALIGN_CENTER_VERTICAL)
         self._h_sizer.Add((12, 12))
         v_sizer.Add((2, 2))
