@@ -36,8 +36,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 321 2007-07-25 07:04:48Z CodyPrecord $"
-__revision__ = "$Revision: 321 $"
+__svnid__ = "$Id: ed_glob.py 398 2007-08-31 11:03:55Z CodyPrecord $"
+__revision__ = "$Revision: 398 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'SB_ROWCOL', 'version', 'prog_name',
             'ID_NEW', 'ID_OPEN', 'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 
@@ -63,7 +63,7 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'SB_ROWCOL', 'version', 'prog_name',
 
 #---- Project Info ----#
 Author = __Author__  = u'Cody Precord'
-version = __version__ = u'0.1.64'
+version = __version__ = u'0.1.78'
 prog_name = u'Editra'
 home_page = u"http://editra.org"
 contact_mail = u"staff@editra.org"
@@ -154,6 +154,7 @@ ID_PRINT_MODE    = wx.NewId()
 ID_TRANSPARENCY  = wx.NewId()
 ID_PREF_SPOS     = wx.NewId()
 ID_PREF_UPDATE_BAR = wx.NewId()
+ID_SESSION       = wx.NewId()
 
 # View Menu IDs
 ID_ZOOM_OUT      = wx.ID_ZOOM_OUT
@@ -163,9 +164,11 @@ ID_SHOW_EDGE     = wx.NewId()
 ID_SHOW_EOL      = wx.NewId()
 ID_SHOW_LN       = wx.NewId()
 ID_SHOW_WS       = wx.NewId()
+ID_SHOW_SHELF    = wx.NewId()
 ID_PERSPECTIVES  = wx.NewId()
 ID_INDENT_GUIDES = wx.NewId()
 ID_VIEW_TOOL     = wx.NewId()
+ID_SHELF         = wx.NewId()
 ID_GOTO_LINE     = wx.NewId()
 ID_NEXT_MARK     = wx.ID_FORWARD
 ID_PRE_MARK      = wx.ID_BACKWARD
@@ -222,6 +225,7 @@ ID_CDROM             = wx.NewId()
 ID_COMMAND_LINE_OPEN = wx.NewId()
 ID_COMMAND_BAR       = wx.NewId()
 ID_COMPUTER          = wx.NewId()
+ID_DELETE            = wx.NewId()
 ID_DOWNLOAD_DLG      = wx.NewId()
 ID_FILE              = wx.ID_FILE
 ID_FLOPPY            = wx.NewId()
@@ -237,10 +241,12 @@ ID_PREF_APPEARANCE   = wx.NewId()
 ID_PREF_DOCUMENT     = wx.NewId()
 ID_PREF_GENERAL      = wx.NewId()
 ID_PREF_UPDATE       = wx.NewId()
+ID_VI_MODE           = wx.NewId()
 
 # Statusbar IDs
 SB_INFO          = 0
-SB_ROWCOL        = 1
+SB_BUFF          = 1
+SB_ROWCOL        = 2
 
 #---- Objects ----#
 
@@ -264,6 +270,7 @@ ID_2_PROF = {
              ID_PREF_SYNTHEME     : 'SYNTHEME',
              ID_PREF_TABS         : 'USETABS',
              ID_PREF_TABW         : 'TABWIDTH',
+             ID_SESSION           : 'SAVE_SESSION',
              ID_SHOW_EDGE         : 'SHOW_EDGE',
              ID_SHOW_EOL          : 'SHOW_EOL',
              ID_SHOW_LN           : 'SHOW_LN',
@@ -278,8 +285,10 @@ ID_2_PROF = {
              ID_PREF_ICON         : 'ICONS',
              ID_PREF_ICONSZ       : 'ICON_SZ',
              ID_PREF_MODE         : 'MODE',
-             ID_PRINT_MODE        : 'PRINT_MODE'
+             ID_PRINT_MODE        : 'PRINT_MODE',
+             ID_VI_MODE           : 'VI_EMU'
 }
 
 # Default Plugins
-DEFAULT_PLUGINS = ("generator.Html", "generator.LaTeX", "generator.Rtf")
+DEFAULT_PLUGINS = ("generator.Html", "generator.LaTeX", "generator.Rtf",
+                   "iface.Shelf")
