@@ -50,8 +50,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 319 2007-07-23 13:26:58Z CodyPrecord $"
-__revision__ = "$Revision: 319 $"
+__svnid__ = "$Id: ed_main.py 383 2007-08-26 12:19:16Z CodyPrecord $"
+__revision__ = "$Revision: 383 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -67,6 +67,7 @@ from profiler import Profile_Get as _PGET
 from profiler import Profile_Set as _PSET
 import profiler
 import ed_toolbar
+import ed_event
 import ed_pages
 import ed_menu
 import ed_print
@@ -75,6 +76,7 @@ import syntax.syntax as syntax
 import generator
 import plugin
 import perspective as viewmgr
+import iface
 
 # Function Aliases
 _ = wx.GetTranslation
@@ -140,8 +142,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self._cmdbar.Hide()
 
         #---- Status bar on bottom of window ----#
-        self.CreateStatusBar(2, style = wx.ST_SIZEGRIP | wx.ST_DOTS_MIDDLE)
-        self.SetStatusWidths([-1, 155])
+        self.CreateStatusBar(3, style = wx.ST_SIZEGRIP | wx.ST_DOTS_MIDDLE)
+        self.SetStatusWidths([-1, 120, 155])
         #---- End Statusbar Setup ----#
 
         #---- Create a toolbar ----#
@@ -270,10 +272,16 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         plgmgr = wx.GetApp().GetPluginManager()
         addons = MainWindowAddOn(plgmgr)
         addons.Init(self)
+        self._shelf = iface.Shelf(plgmgr)
+        self._shelf.Init(self)
         self.LOG("[main][info] Loading Generator plugins")
         self._generator = generator.Generator(plgmgr)
         self._generator.InstallMenu(self.toolsmenu)
 
+        # Load Session Data
+        if _PGET('SAVE_SESSION', 'bool', False):
+            self.nb.LoadSessionFiles()
+
         # Set Perspective
         self.SetPerspective(_PGET('DEFAULT_VIEW'))
         self._mgr.Update()
@@ -301,11 +309,13 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         if e_id == ID_OPEN:
             dlg = wx.FileDialog(self, _("Choose a File"), '', "", 
                                 self.MenuFileTypes(), wx.OPEN | wx.MULTIPLE)
+            dlg.SetFilterIndex(_PGET('FFILTER', 'int', 0))
             if dlg.ShowModal() == wx.ID_OK:
                 paths = dlg.GetPaths()
                 dlg.Destroy()
                 result = dlg.GetReturnCode()
 
+            _PSET('FFILTER', dlg.GetFilterIndex())
             if result != wx.ID_CANCEL:
                 for path in paths:
                     dirname = util.GetPathName(path)
@@ -581,6 +591,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         # Cleanup Controls
         controls = self.nb.GetPageCount()
+        _PSET('LAST_SESSION', self.nb.GetFileNames())
         self.LOG("[main_evt] [exit] Number of controls: %d" % controls)
 
         self._exiting = True
@@ -613,6 +624,9 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self.nb.DocMgr.WriteBook()
         syntax.SyntaxMgr().SaveState()
 
+        # Save Shelf contents
+        _PSET('SHELF_ITEMS', self._shelf.GetItemStack())
+
         # Save Window Size/Position for next launch
         # XXX workaround for possible bug in wxPython 2.8
         if wx.Platform == '__WXMAC__' and self.GetToolBar():
@@ -634,6 +648,13 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             self.LOG("[main][exit][err] Trapped AttributeError OnExit")
         self._cmdbar.Destroy()
 
+        # Post exit notice to all aui panes
+        panes = self._mgr.GetAllPanes()
+        exit_evt = ed_event.MainWindowExitEvent(ed_event.edEVT_MAINWINDOW_EXIT,
+                                                wx.ID_ANY)
+        for pane in panes:
+            wx.PostEvent(pane.window, exit_evt)
+
         # Finally close the application
         self.LOG("[main_info] Closing Main Frame")
         wx.GetApp().UnRegisterWindow(repr(self))
