@@ -34,8 +34,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: ed_menu.py 282 2007-07-11 09:27:53Z CodyPrecord $"
-__revision__ = "$Revision: 282 $"
+__svnid__ = "$Id: ed_menu.py 361 2007-08-19 00:09:10Z CodyPrecord $"
+__revision__ = "$Revision: 361 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -97,7 +97,7 @@ class ED_Menu(wx.Menu):
         return item
 
     def InsertAfter(self, item_id, id_, label=u'', helpstr=u'', 
-                    kind = wx.ITEM_NORMAL, use_bmp=True):
+                    kind=wx.ITEM_NORMAL, use_bmp=True):
         """Inserts the given item after the specified item id in
         the menu. If the id cannot be found then the item will appended
         to the end of the menu.
@@ -264,10 +264,13 @@ class EdMenuBar(wx.MenuBar):
         filemenu.Append(ed_glob.ID_SAVEALL, _("Save All"), \
                         _("Save all open pages")) 
         filemenu.AppendSeparator()
-        filemenu.Append(ed_glob.ID_SAVE_PROFILE, _("Save Profile"), 
-                             _("Save Current Settings to a New Profile"))
-        filemenu.Append(ed_glob.ID_LOAD_PROFILE, _("Load Profile"), 
-                        _("Load a Custom Profile"))
+        pmenu = ED_Menu()
+        pmenu.Append(ed_glob.ID_SAVE_PROFILE, _("Save Profile"), 
+                     _("Save Current Settings to a New Profile"))
+        pmenu.Append(ed_glob.ID_LOAD_PROFILE, _("Load Profile"), 
+                     _("Load a Custom Profile"))
+        filemenu.AppendSubMenu(pmenu, _("Profile"), 
+                               _("Load and save custom rofiles"))
         filemenu.AppendSeparator()
         filemenu.Append(ed_glob.ID_PRINT_SU, _("Page Setup") + "\tCtrl+Shift+P",
                         _("Configure Printer"))
