@@ -42,8 +42,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 310 2007-07-22 02:29:01Z CodyPrecord $"
-__revision__ = "$Revision: 310 $"
+__svnid__ = "$Id: ed_pages.py 369 2007-08-20 07:55:44Z CodyPrecord $"
+__revision__ = "$Revision: 369 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -52,7 +52,7 @@ import glob
 import re
 import wx
 import ed_glob
-from profiler import Profile_Get
+from profiler import Profile_Get, Profile_Set
 import ed_event
 import ed_stc
 import syntax.synglob as synglob
@@ -63,9 +63,8 @@ import doctools
 # Use local copy until newer release of wxpython
 from extern import flatnotebook as FNB
 
-#---- Class Globals ----#
-# HACK till proper artprovider can be written
-IMG = {}
+#--------------------------------------------------------------------------#
+# Globals
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
@@ -144,6 +143,33 @@ class EdPages(FNB.FlatNotebook):
         else:
             return None
 
+    def GetFileNames(self):
+        """Gets the name of all open files in the notebook
+        @return: list of file names
+
+        """
+        rlist = list()
+        for buff in self.GetTextControls():
+            fname = buff.GetFileName()
+            if fname != wx.EmptyString:
+                rlist.append(fname)
+        return rlist
+
+    def LoadSessionFiles(self):
+        """Load files from saved session data in profile
+        @postcondition: Files saved from previous session are
+                        opened. If no files were found then only a
+                        single blank page is opened.
+
+        """
+        files = Profile_Get('LAST_SESSION')
+        if files is not None:
+            for file in files:
+                self.OpenPage(os.path.dirname(file), os.path.basename(file))
+
+        if self.GetPageCount() == 0:
+            self.NewPage()
+
     def NewPage(self):
         """Create a new notebook page with a blank text control
         @postcondition: a new page with an untitled document is opened
@@ -185,6 +211,12 @@ class EdPages(FNB.FlatNotebook):
             result = mdlg.ShowModal()
             mdlg.Destroy()
             if result == wx.ID_NO:
+                for page in xrange(self.GetPageCount()):
+                    ctrl = self.GetPage(page)
+                    if path2file == os.path.join(ctrl.dirname, ctrl.filename):
+                        self.SetSelection(page)
+                        self.ChangePage(page)
+                        break
                 return
 
         # Create new control to place text on if necessary
@@ -444,20 +476,18 @@ class EdPages(FNB.FlatNotebook):
     def OnPageChanging(self, evt):
         """Page changing event handler.
         @param evt: event that called this handler
-        @type evt: wx.lib.flatnotebook.EVT_FLATNOTEBOOK_PAGE_CHANGING
+        @type evt: flatnotebook.EVT_FLATNOTEBOOK_PAGE_CHANGING
 
         """
         self.LOG("[nb_evt] Page Changed to %d" % evt.GetSelection())
         evt.Skip()
 
-    def OnPageChanged(self, evt):
-        """Actions to do after a page change
-        @param evt: event that called this handler
-        @type evt: wx.lib.flatnotebook.EVT_FLATNOTEBOOK_PAGE_CHANGED
+    def ChangePage(self, pgid):
+        """Change the page and focus to the the given page id
+        @param pgid: Page number to change to
 
         """
-        current = evt.GetSelection()
-        window = self.GetPage(current) #returns current stc
+        window = self.GetPage(pgid) #returns current stc
         window.SetFocus()
         self.control = window
 
@@ -476,6 +506,14 @@ class EdPages(FNB.FlatNotebook):
         self.control.Bind(wx.EVT_KEY_UP, self.frame.OnKeyUp)
         self.control.Bind(wx.EVT_LEFT_UP, self.frame.OnKeyUp)
 
+    def OnPageChanged(self, evt):
+        """Actions to do after a page change
+        @param evt: event that called this handler
+        @type evt: wx.lib.flatnotebook.EVT_FLATNOTEBOOK_PAGE_CHANGED
+
+        """
+        current = evt.GetSelection()
+        self.ChangePage(current)
         self.LOG(("[nb_evt] Control Changing from Page: %d to Page: %d\n"
                  "[nb_info] It has file named: %s\n"
                  "[nb_info] In DIR: %s") % (evt.GetOldSelection(), 
