@@ -35,8 +35,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 317 2007-07-22 06:20:46Z CodyPrecord $"
-__revision__ = "$Revision: 317 $"
+__svnid__ = "$Id: ed_search.py 325 2007-07-30 03:24:20Z CodyPrecord $"
+__revision__ = "$Revision: 325 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -195,7 +195,8 @@ class TextFinder(object):
         @param evt: event that called this handler
 
         """
-        self._find_dlg.Destroy()
+        if self._find_dlg is not None:
+            self._find_dlg.Destroy()
         self._find_dlg = None
         evt.Skip()
 
@@ -205,7 +206,7 @@ class TextFinder(object):
         @postcondition: find dialog is shown
 
         """
-        if self._find_dlg != None:
+        if self._find_dlg is not None:
             self._find_dlg.Destroy()
             self._find_dlg = None
         e_id = evt.GetId()
