@@ -45,13 +45,14 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 310 2007-07-22 02:29:01Z CodyPrecord $"
-__revision__ = "$Revision: 310 $"
+__svnid__ = "$Id: ed_stc.py 392 2007-08-30 17:38:53Z CodyPrecord $"
+__revision__ = "$Revision: 392 $"
 
 #-------------------------------------------------------------------------#
 # Dependencies
 
 import os
+import re
 import wx, wx.stc
 import ed_event
 import ed_glob
@@ -61,10 +62,24 @@ from autocomp import autocomp
 import util
 import ed_style
 
+#-------------------------------------------------------------------------#
+# Globals
+
 _ = wx.GetTranslation
 MARK_MARGIN = 0
 NUM_MARGIN  = 1
 FOLD_MARGIN = 2
+
+# Vi command patterns
+VI_DCMD_RIGHT = '[bBcdeEGhHlLMwWy|{}$<>]'
+VI_DOUBLE_P1 = re.compile('[cdy<>][0-9]*' + VI_DCMD_RIGHT)
+VI_DOUBLE_P2 = re.compile('[0-9]*[cdy<>]' + VI_DCMD_RIGHT)
+VI_SINGLE_REPEAT = re.compile('[0-9]*[bBCDeEGhjJkloOpPsuwWxX{}~|+-]')
+NUM_PAT = re.compile('[0-9]*')
+NONSPACE = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" + \
+           "0123456789_./\?[]{}<>!@#$%^&*():=-+\"';,"
+SPACECHARS = " \t\r\n"
+
 #-------------------------------------------------------------------------#
 class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
     """Defines a styled text control for editing text
@@ -72,8 +87,9 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
               L{ed_style.StyleMgr}. Manages the documents display
               and input.
 
-              """
+    """
     ED_STC_MASK_MARKERS = ~wx.stc.STC_MASK_FOLDERS
+
     def __init__(self, parent, id_,
                  pos=wx.DefaultPosition, size=wx.DefaultSize,
                  style=0, use_dt=True):
@@ -101,6 +117,10 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         # Attributes
         self.LOG = wx.GetApp().GetLog()
+        self._vimode = False
+        self._vinormal = False
+        self._vilast = u''
+        self._cmdcache = u''
 
         # File Attributes
         self.filename = ''	                # This controls File
@@ -240,6 +260,26 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.InsertText(pos, self.GetEOLChar())
         self.GotoPos(pos + curr)
 
+    def AutoIndent(self):
+        """Indent from the current postion to match the indentation
+        of the previous line.
+        @postcondition: proper type of white space is added from current pos
+                        to match that of indentation in above line
+        """
+        line = self.GetCurrentLine()
+        text = self.GetTextRange(self.PositionFromLine(line), \
+                                 self.GetCurrentPos())
+        if text.strip() == u'':
+            self.AddText(self.GetEOLChar() + text)
+            self.EnsureCaretVisible()
+            return
+        indent = self.GetLineIndentation(line)
+        i_space = indent / self.GetTabWidth()
+        ndent = self.GetEOLChar() + self.GetIndentChar() * i_space
+        self.AddText(ndent + \
+                     ((indent - (self.GetTabWidth() * i_space)) * u' '))
+        self.EnsureCaretVisible()
+
     def Bookmark(self, action):
         """Handles bookmark actions
         @param action: An event ID that describes what is to be done
@@ -289,6 +329,7 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.ToggleAutoIndent(_PGET('AUTO_INDENT'))
         self.ToggleBracketHL(_PGET('BRACKETHL'))
         self.ToggleLineNumbers(_PGET('SHOW_LN'))
+        self.SetViEmulationMode(_PGET('VI_EMU'))
         self.SetViewEdgeGuide(_PGET('SHOW_EDGE'))
 
     def Comment(self, uncomment=False):
@@ -342,12 +383,22 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @keyword to_upper: Flag whether conversion is to upper case or not.
 
         """
-        txt = self.GetSelectedText()
         if to_upper:
-            txt = txt.upper()
+            self.UpperCase()
         else:
-            txt = txt.lower()
-        self.ReplaceSelection(txt)
+            self.LowerCase()
+
+    def InvertCase(self):
+        """Invert the case of the selected text
+        @postcondition: all text in selection has case inverted
+
+        """
+        text = self.GetSelectedText()
+        if len(text) > 0:
+            text = text.swapcase()
+            self.BeginUndoAction()
+            self.ReplaceSelection(text)
+            self.EndUndoAction()
 
     def GetAutoIndent(self):
         """Returns whether auto-indent is being used
@@ -365,6 +416,26 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         return self.lang_id
 
+    def GetLastVisibleLine(self):
+        """Return what the last visible line is
+        @return: int
+
+        """
+        fline = self.GetFirstVisibleLine()
+        return fline + self.LinesOnScreen() - 1
+
+    def GetMiddleVisibleLine(self):
+        """Return the number of the line that is in the middle of the display
+        @return: int
+
+        """
+        fline = self.GetFirstVisibleLine()
+        if self.LinesOnScreen() < self.GetLineCount():
+            mid = (fline + (self.LinesOnScreen() / 2))
+        else:
+            mid = (fline + (self.GetLineCount() / 2))
+        return mid
+
     def GetPos(self, key):
         """Update Line/Column information
         @param key: KeyEvent object
@@ -383,6 +454,41 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         else:
             return (-1, -1)
 
+    def GotoColumn(self, column):
+        """Move caret to column of current line
+        @param column: Column to move to
+
+        """
+        cline = self.GetCurrentLineNum()
+        lstart = self.PositionFromLine(cline)
+        lend = self.GetLineEndPosition(cline)
+        linelen = lend - lstart
+        if column > linelen:
+            column = linelen
+        self.GotoPos(lstart + column)
+
+    def SetCurrentCol(self, column):
+        """Set the current column position on the currently line
+        extending the selection.
+        @param column: Column to move to
+
+        """
+        cline = self.GetCurrentLineNum()
+        lstart = self.PositionFromLine(cline)
+        lend = self.GetLineEndPosition(cline)
+        linelen = lend - lstart
+        if column > linelen:
+            column = linelen
+        self.SetCurrentPos(lstart + column)
+
+    def GotoIndentPos(self, line):
+        """Move the caret to the end of the indentation
+        on the given line.
+        @param line: line to go to
+
+        """
+        self.GotoPos(self.GetLineIndentPosition(line))
+
     def DefineMarkers(self):
         """Defines the folder and bookmark icons for this control
         @postcondition: all margin markers are defined
@@ -432,7 +538,11 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @return: full path name of document
 
         """
-        return "".join([self.dirname, util.GetPathChar(), self.filename])
+        fname = "".join([self.dirname, util.GetPathChar(), self.filename])
+        if fname == util.GetPathChar():
+            return wx.EmptyString
+        else:
+            return fname
 
     def GetStyleSheet(self, sheet_name=None):
         """Finds the current style sheet and returns its path. The
@@ -468,23 +578,17 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         k_code = evt.GetKeyCode()
+        if self._vimode and k_code == wx.WXK_ESCAPE:
+            # If Vi emulation is active go into Normal mode and
+            # pass the key event to OnChar
+            self.SetViNormalMode(True)
+            evt.Skip()
+            return
         if self._autoindent and k_code == wx.WXK_RETURN:
             if self.GetSelectedText():
                 self.CmdKeyExecute(wx.stc.STC_CMD_NEWLINE)
                 return
-            line = self.GetCurrentLine()
-            text = self.GetTextRange(self.PositionFromLine(line), \
-                                     self.GetCurrentPos())
-            if text.strip() == u'':
-                self.AddText(self.GetEOLChar() + text)
-                self.EnsureCaretVisible()
-                return
-            indent = self.GetLineIndentation(line)
-            i_space = indent / self.GetTabWidth()
-            ndent = self.GetEOLChar() + self.GetIndentChar() * i_space
-            self.AddText(ndent + \
-                         ((indent - (self.GetTabWidth() * i_space)) * u' '))
-            self.EnsureCaretVisible()
+            self.AutoIndent()
         else:
             evt.Skip()
 
@@ -498,10 +602,14 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                prevent a slow down in the input of text into the buffer
 
         """
+        key_code = evt.GetKeyCode()
+        if self._vimode and self._vinormal:
+            self._cmdcache = self._cmdcache + unichr(key_code)
+            self.ViCmdDispatch()
+            return
         if not self._use_autocomp:
             evt.Skip()
             return True
-        key_code = evt.GetKeyCode()
         if key_code in self._autocomp_svc.GetAutoCompKeys():
             if self.AutoCompActive():
                 self.AutoCompCancel()
@@ -540,7 +648,32 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 #                 self._macro.append(mac)
         else:
             evt.Skip()
-            
+
+    def ParaDown(self):
+        """Move the caret one paragraph down
+        @note: overrides the default function to set caret at end
+               of paragraph instead of jumping to start of next
+
+        """
+        self.WordPartRight()
+        wx.stc.StyledTextCtrl.ParaDown(self)
+        if self.GetCurrentPos() != self.GetLength():
+            self.WordPartLeft()
+            self.GotoPos(self.GetCurrentPos() + len(self.GetEOLChar()))
+
+    def ParaDownExtend(self):
+        """Extend the selection a paragraph down
+        @note: overrides the default function to set selection at end
+               of paragraph instead of jumping to start of next so that
+               extra blank lines don't get swallowed.
+
+        """
+        self.WordRightExtend()
+        wx.stc.StyledTextCtrl.ParaDownExtend(self)
+        if self.GetCurrentPos() != self.GetLength():
+            self.WordLeftExtend()
+            self.SetCurrentPos(self.GetCurrentPos() + len(self.GetEOLChar()))
+
     def GetCommandStr(self):
         """Gets the command string to the left of the autocomp
         activation character.
@@ -948,6 +1081,14 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.EndUndoAction()
             del part1
 
+    def GetCurrentLineNum(self):
+        """Return the number of the line that the caret is currently at
+        @return: Line number (int)
+
+        """
+        cpos = self.GetCurrentPos()
+        return self.LineFromPosition(cpos)
+
     def GetEOLChar(self):
         """Gets the eol character used in document
         @returns the character used for eol in this document
@@ -1028,6 +1169,23 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         return self.recording
 
+    def LinesJoin(self):
+        """Join lines in target and compress whitespace
+        @note: overrides default function to allow for leading
+               whitespace in joined lines to be compressed to 1 space
+
+        """
+        sline = self.LineFromPosition(self.GetTargetStart())
+        eline = self.LineFromPosition(self.GetTargetEnd())
+        if not eline:
+            eline = 1
+        lines = list()
+        for line in xrange(sline, eline + 1):
+            lines.append(self.GetLine(line).strip())
+        self.SetTargetStart(self.PositionFromLine(sline))
+        self.SetTargetEnd(self.GetLineEndPosition(eline))
+        self.ReplaceTarget(u' '.join(lines))
+
     def SetAutoComplete(self, value):
         """Turns Autocompletion on and off
         @param value: use autocomp or not
@@ -1059,6 +1217,35 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         mode = mode_map.get(mode_str, wx.stc.STC_EOL_LF)
         self.SetEOLMode(mode)
 
+    def SetViEmulationMode(self, use_vi):
+        """Activate/Deactivate Vi eumulation mode
+        @param use_vi: Turn vi emulation on/off
+        @type use_vi: boolean
+
+        """
+        self._vimode = use_vi
+        self.SetViNormalMode(False)  # Use input mode by default
+        self._cmdcache = u'' # clear all cmds when switching modes
+
+    def SetViNormalMode(self, normal):
+        """Change the cursor appearance when toggling
+        in and out of vi normal mode.
+        @param normal: Normal mode on/off
+        @type normal: boolean
+
+        """
+        self._vinormal = normal
+        self._cmdcache = u''
+        mw = wx.GetApp().GetMainWindow()
+        if normal:
+            self.SetCaretWidth(10)
+            if mw:
+                mw.SetStatusText('NORMAL', ed_glob.SB_BUFF)
+        else:
+            self.SetCaretWidth(1)
+            if mw:
+                mw.SetStatusText('INSERT', ed_glob.SB_BUFF)
+
     def SetViewEdgeGuide(self, switch=None):
         """Toggles the visibility of the edge guide
         @keyword switch: force a particular setting
@@ -1120,6 +1307,302 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.GotoPos(cpos)
         del txt
 
+    def ViCmdDispatch(self):
+        """Processes vi commands
+        @todo: complete rewrite, this was initially intended for testing but
+               now has implemented everything.
+
+        """
+        if not len(self._cmdcache):
+            return
+
+        if self._cmdcache != u'.':
+            cmd = self._cmdcache
+        else:
+            cmd = self._vilast
+        cpos = self.GetCurrentPos()
+        cline = self.LineFromPosition(cpos)
+        mw = wx.GetApp().GetMainWindow()
+        # Single key commands
+        if len(cmd) == 1 and (cmd in 'AHILmM0^$nia/?:'):
+            if  cmd in u'A$': # Insert at EOL
+                self.GotoPos(self.GetLineEndPosition(cline))
+            elif cmd == u'H': # Go first visible line # todo allow num
+                self.GotoIndentPos(self.GetFirstVisibleLine())
+            elif cmd in u'I^': # Insert at line start / Jump line start
+                self.GotoIndentPos(cline)
+            elif cmd == u'0': # Jump to line start column 0
+                self.GotoPos(self.PositionFromLine(cline))
+            elif cmd == u'L': # Goto start of last visible line # todo allow num
+                self.GotoIndentPos(self.GetLastVisibleLine())
+            elif cmd == u'M': # Goto middle line of display
+                self.GotoIndentPos(self.GetMiddleVisibleLine())
+            elif cmd == u'm': # Mark line
+                if self.MarkerGet(cline):
+                    self.Bookmark(ed_glob.ID_DEL_BM)
+                else:
+                    self.Bookmark(ed_glob.ID_ADD_BM)
+            elif cmd == u'a': # insert mode after current pos
+                self.GotoPos(cpos + 1)
+            elif cmd in u'/?:':
+                if mw is not None:
+                    if cmd in u'/?':
+                        mid = ed_glob.ID_QUICK_FIND
+                    else:
+                        mid = ed_glob.ID_GOTO_LINE
+                    evt = wx.MenuEvent(wx.wxEVT_COMMAND_MENU_SELECTED, mid)
+                    wx.PostEvent(mw, evt)
+            if cmd in u'aAiI':
+                self.SetViNormalMode(False)
+
+            self._vilast = cmd
+            self._cmdcache = u''
+        # Repeatable 1 key commands
+        elif re.match(VI_SINGLE_REPEAT, cmd):
+            rcmd = cmd[-1]
+            repeat = cmd[0:-1]
+            if repeat == u'':
+                repeat = 1
+            else:
+                repeat = int(repeat)
+
+            args = list()
+            kargs = dict()
+            cmd_map = { u'b' : self.WordPartLeft,
+                       u'B' : self.WordLeft,
+                       u'e' : self.WordPartRightEnd,
+                       u'E' : self.WordRightEnd,
+                       u'h' : self.CharLeft,
+                       u'j' : self.LineDown,
+                       u'k' : self.LineUp,
+                       u'l' : self.CharRight,
+                       u'o' : self.AddLine,
+                       u'O' : self.AddLine,
+                       u'p' : self.Paste,
+                       u'P' : self.Paste,
+                       u's' : self.Cut,
+                       u'u' : self.Undo,
+                       u'w' : self.WordPartRight,
+                       u'W' : self.WordRight,
+                       u'x' : self.Cut,
+                       u'X' : self.Cut,
+                       u'{' : self.ParaUp,
+                       u'}' : self.ParaDown,
+                       u'~' : self.InvertCase }
+
+            if rcmd in u'pP':
+                success = False
+                newline = False
+                if wx.TheClipboard.Open():
+                    td = wx.TextDataObject()
+                    success = wx.TheClipboard.GetData(td)
+                    wx.TheClipboard.Close()
+                if success:
+                    text = td.GetText()
+                    if text[-1] == '\n':
+                        if cline == self.GetLineCount() - 1 and rcmd == u'p':
+                            self.NewLine()
+                        else:
+                            if rcmd == u'P':
+                                self.GotoLine(cline)
+                            else:
+                                self.GotoLine(cline + 1)
+                        newline = True
+                    elif rcmd == u'p' and \
+                         self.LineFromPosition(cpos + 1) == cline:
+                        self.CharRight()
+            elif rcmd in u'sxX~':
+                if rcmd in u'sx~':
+                    tmp = self.GetTextRange(cpos, cpos + repeat)
+                    tmp = tmp.split(self.GetEOLChar())
+                    end = cpos + len(tmp[0])
+                else:
+                    tmp = self.GetTextRange(cpos - repeat, cpos)
+                    tmp = tmp.split(self.GetEOLChar())
+                    end = cpos - len(tmp[-1])
+                    tmp = end
+                    end = cpos
+                    cpos = tmp
+
+                if cpos == self.GetLineEndPosition(cline):
+                    self.SetSelection(cpos - 1, cpos)
+                else:
+                    self.SetSelection(cpos, end)
+                repeat = 1
+            elif rcmd == u'O':
+                kargs['before'] = True
+
+            self.BeginUndoAction()
+            if rcmd in u'CD': # Cut line right
+                self.SetSelection(cpos, 
+                                  self.GetLineEndPosition(cline + (repeat - 1)))
+                self.Cut()
+            elif rcmd == u'J':
+                self.SetTargetStart(cpos)
+                self.SetTargetEnd(self.PositionFromLine(cline + repeat - 1))
+                self.LinesJoin()
+            elif rcmd == u'G':
+                if repeat == 1 and '1' not in cmd:
+                    repeat = self.GetLineCount()
+                self.GotoLine(repeat - 1)
+            elif rcmd == u'+':
+                self.GotoIndentPos(cline + repeat)
+            elif rcmd == u'-':
+                self.GotoIndentPos(cline - repeat)
+            elif rcmd == u'|':
+                self.GotoColumn(repeat - 1)
+            else:
+                if not cmd_map.has_key(rcmd):
+                    return
+                run = cmd_map[rcmd]
+                for count in xrange(repeat):                
+                    run(*args, **kargs)
+            if rcmd == u'p':
+                if newline:
+                    self.GotoIndentPos(cline + repeat)
+                else:
+                    self.GotoPos(cpos + 1)
+            elif rcmd == u'P':
+                if newline:
+                    self.GotoIndentPos(cline)
+                else:
+                    self.GotoPos(cpos)
+#             elif rcmd == u'u':
+#                 self.GotoPos(cpos)
+            elif rcmd in u'CoOs':
+                self.SetViNormalMode(False)
+            self.EndUndoAction()
+            self._vilast = cmd
+            self._cmdcache = u''
+        # 2 key commands
+        elif re.match(VI_DOUBLE_P1, cmd) or \
+             re.match(VI_DOUBLE_P2, cmd) or \
+             re.match(re.compile('[cdy]0'), cmd):
+            if re.match(re.compile('[cdy]0'), cmd):
+                rcmd = cmd
+            else:
+                rcmd = re.sub(NUM_PAT, u'', cmd)
+            repeat = re.subn(re.compile(VI_DCMD_RIGHT), u'', cmd, 2)[0]
+            if repeat == u'':
+                repeat = 1
+            else:
+                repeat = int(repeat)
+
+            if rcmd[-1] not in u'bBeEGhHlLMwW$|{}0':
+                self.GotoLine(cline)
+                if repeat != 1 or rcmd not in u'>><<':
+                    self.SetSelectionStart(self.GetCurrentPos())
+                    self.SetSelectionEnd(self.PositionFromLine(cline + repeat))
+            else:
+                self.SetAnchor(self.GetCurrentPos())
+                mcmd = { u'b' : self.WordPartLeftExtend,
+                         u'B' : self.WordLeftExtend,
+                         u'e' : self.WordPartRightEndExtend,
+                         u'E' : self.WordRightEndExtend,
+                         u'h' : self.CharLeftExtend,
+                         u'l' : self.CharRightExtend,
+                         u'w' : self.WordPartRightExtend,
+                         u'W' : self.WordRightExtend,
+                         u'{' : self.ParaUpExtend,
+                         u'}' : self.ParaDownExtend}
+
+                if u'$' in rcmd:
+                    pos = self.GetLineEndPosition(cline + repeat - \
+                                                  len(self.GetEOLChar()))
+                    self.SetCurrentPos(pos)
+                elif u'G' in rcmd:
+                    if repeat == 0: # invalid cmd
+                        self._cmdcache = u''
+                        return
+                    if repeat == 1 and u'1' not in cmd: # Default eof
+                        self.SetAnchor(self.GetLineEndPosition(cline - 1))
+                        repeat = self.GetLength()
+                    elif repeat < cline + 1:
+                        self.SetAnchor(self.PositionFromLine(cline + 1))
+                        repeat = self.PositionFromLine(repeat - 1)
+                        cline = self.LineFromPosition(repeat) - 1
+                    elif repeat > cline:
+                        self.SetAnchor(self.GetLineEndPosition(cline - 1))
+                        if cline == 0:
+                            repeat = self.PositionFromLine(repeat)
+                        else:
+                            repeat = self.GetLineEndPosition(repeat - 1)
+                    else:
+                        self.SetAnchor(self.PositionFromLine(cline))
+                        repeat = self.PositionFromLine(cline + 1)
+                    self.SetCurrentPos(repeat)
+                elif rcmd[-1] in u'HM':
+                    fline = self.GetFirstVisibleLine()
+                    lline = self.GetLastVisibleLine()
+
+                    if u'M' in rcmd:
+                        repeat = self.GetMiddleVisibleLine() + 1
+                    elif fline + repeat > lline:
+                        repeat = lline
+                    else:
+                        repeat = fline + repeat
+
+                    if repeat > cline:
+                        self.SetAnchor(self.PositionFromLine(cline))
+                        self.SetCurrentPos(self.PositionFromLine(repeat))
+                    else:
+                        self.SetAnchor(self.PositionFromLine(repeat - 1))
+                        self.SetCurrentPos(self.PositionFromLine(cline + 1))
+                elif u'L' in rcmd:
+                    fline = self.GetFirstVisibleLine()
+                    lline = self.GetLastVisibleLine()
+                    if lline - repeat < fline:
+                        repeat = fline
+                    else:
+                        repeat = lline - repeat
+
+                    if repeat < cline:
+                        self.SetAnchor(self.PositionFromLine(cline))
+                        self.SetCurrentPos(self.PositionFromLine(repeat))
+                    else:
+                        self.SetAnchor(self.PositionFromLine(cline))
+                        self.SetCurrentPos(self.PositionFromLine(repeat + 2))
+                elif u'|' in rcmd:
+                    if repeat == 1 and u'1' not in cmd:
+                        repeat = 0
+                    self.SetCurrentCol(repeat)
+                elif rcmd[-1] == u'0':
+                    self.SetCurrentCol(0)
+                else:
+                    doit = mcmd[rcmd[-1]]
+                    for x in xrange(repeat):
+                        doit()
+
+            self.BeginUndoAction()
+            if re.match(re.compile('c|c' + VI_DCMD_RIGHT), rcmd):
+                if rcmd == u'cc':
+                    self.SetSelectionEnd(self.GetSelectionEnd() - \
+                                         len(self.GetEOLChar()))
+                self.Cut()
+                self.SetViNormalMode(False)
+            elif re.match(re.compile('d|d' + VI_DCMD_RIGHT), rcmd):
+                self.Cut()
+            elif re.match(re.compile('y|y' + VI_DCMD_RIGHT), rcmd):
+                self.Copy()
+                self.GotoPos(cpos)
+            elif rcmd == u'<<':
+                self.BackTab()
+            elif rcmd == u'>>':
+                self.Tab()
+            else:
+                pass
+            self.EndUndoAction()
+            if rcmd in '<<>>' or rcmd[-1] == u'G':
+                self.GotoIndentPos(cline)
+            self._vilast = cmd
+            self._cmdcache = u''
+        else:
+            pass
+
+        # Update status bar
+        if mw and self._vinormal:
+            mw.SetStatusText('NORMAL\t%s' % self._cmdcache, ed_glob.SB_BUFF)
+        
     def FoldingOnOff(self, switch=None):
         """Turn code folding on and off
         @keyword switch: force a particular setting
@@ -1189,6 +1672,128 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.LOG("[stc_evt] Hiding Line Numbers")
             self.SetMarginWidth(NUM_MARGIN, 0)
 
+    def WordLeft(self):
+        """Move caret to begining of previous word
+        @note: override builtin to include extra characters in word
+
+        """
+        self.SetWordChars(NONSPACE)
+        wx.stc.StyledTextCtrl.WordLeft(self)
+        cpos = self.GetCurrentPos()
+        if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
+            wx.stc.StyledTextCtrl.WordLeft(self)
+        self.SetWordChars('')
+
+    def WordLeftExtend(self):
+        """Extend selection to begining of previous word
+        @note: override builtin to include extra characters in word
+
+        """
+        self.SetWordChars(NONSPACE)
+        wx.stc.StyledTextCtrl.WordLeftExtend(self)
+        cpos = self.GetCurrentPos()
+        if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
+            wx.stc.StyledTextCtrl.WordLeftExtend(self)
+        self.SetWordChars('')
+
+    def WordPartLeft(self):
+        """Move the caret left to the next change in capitalization/puncuation
+        @note: overrides default function to not count whitespace as words
+
+        """
+        wx.stc.StyledTextCtrl.WordPartLeft(self)
+        cpos = self.GetCurrentPos()
+        if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
+            wx.stc.StyledTextCtrl.WordPartLeft(self)
+
+    def WordPartLeftExtend(self):
+        """Extend selection left to the next change in capitalization/puncuation
+        @note: overrides default function to not count whitespace as words
+
+        """
+        wx.stc.StyledTextCtrl.WordPartLeftExtend(self)
+        cpos = self.GetCurrentPos()
+        if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
+            wx.stc.StyledTextCtrl.WordPartLeftExtend(self)
+
+    def WordPartRight(self):
+        """Move the caret to the start of the next word part to the right
+        @note: overrides default function to exclude white space
+
+        """
+        wx.stc.StyledTextCtrl.WordPartRight(self)
+        cpos = self.GetCurrentPos()
+        if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
+            wx.stc.StyledTextCtrl.WordPartRight(self)
+
+    def WordPartRightEnd(self):
+        """Move caret to end of next change in capitalization/puncuation
+        @postcondition: caret is moved
+
+        """
+        wx.stc.StyledTextCtrl.WordPartRight(self)
+        wx.stc.StyledTextCtrl.WordPartRight(self)
+        cpos = self.GetCurrentPos()
+        if self.GetTextRange(cpos, cpos - 1) in SPACECHARS:
+            self.CharLeft()
+
+    def WordPartRightEndExtend(self):
+        """Extend selection to end of next change in capitalization/puncuation
+        @postcondition: selection is extended
+
+        """
+        wx.stc.StyledTextCtrl.WordPartRightExtend(self)
+        wx.stc.StyledTextCtrl.WordPartRightExtend(self)
+        cpos = self.GetCurrentPos()
+        if self.GetTextRange(cpos, cpos - 1) in SPACECHARS:
+            self.CharLeftExtend()
+
+    def WordPartRightExtend(self):
+        """Extend selection to start of next change in capitalization/puncuation
+        @postcondition: selection is extended
+
+        """
+        wx.stc.StyledTextCtrl.WordPartRightExtend(self)
+        cpos = self.GetCurrentPos()
+        if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
+            wx.stc.StyledTextCtrl.WordPartRightExtend(self)
+
+    def WordRight(self):
+        """Move caret to begining of next word
+        @note: override builtin to include extra characters in word
+
+        """
+        self.SetWordChars(NONSPACE)
+        wx.stc.StyledTextCtrl.WordRight(self)
+        cpos = self.GetCurrentPos()
+        if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
+            wx.stc.StyledTextCtrl.WordRight(self)
+        self.SetWordChars('')
+
+    def WordRightEnd(self):
+        """Move caret to end of next change in word
+        @note: override builtin to include extra characters in word
+
+        """
+        self.SetWordChars(NONSPACE)
+        wx.stc.StyledTextCtrl.WordRightEnd(self)
+        cpos = self.GetCurrentPos()
+        if self.GetTextRange(cpos, cpos - 1) in SPACECHARS:
+            wx.stc.StyledTextCtrl.WordRightEnd(self)
+        self.SetWordChars('')
+
+    def WordRightExtend(self):
+        """Extend selection to begining of next word
+        @note: override builtin to include extra characters in word
+
+        """
+        self.SetWordChars(NONSPACE)
+        wx.stc.StyledTextCtrl.WordRightExtend(self)
+        cpos = self.GetCurrentPos()
+        if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
+            wx.stc.StyledTextCtrl.WordRightExtend(self)
+        self.SetWordChars('')
+
     def ReloadFile(self):
         """Reloads the current file, returns True on success and
         False if there is a failure.
@@ -1233,10 +1838,17 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                 bom = u''
             writer.write(bom + self.GetText())
             writer.close()
-        except IOError:
+        except IOError, msg:
             writer.close()
             result = False
             self.LOG("[stc][err]There was an error saving %s" % path)
+            self.LOG("[stc][err] ERROR: %s" % str(msg))
+        except AttributeError, msg:
+            # Failed to open writer
+            result = False
+            self.LOG("[stc][err]There was an error saving %s" % path)
+            self.LOG("[stc][err] ERROR: %s" % str(msg))
+
         if result:
             self.SetSavePoint()
             self.modtime = util.GetFileModTime(path)
@@ -1500,3 +2112,5 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.Refresh()
 
     #---- End Style Definitions ----#
+
+#-----------------------------------------------------------------------------#
