@@ -43,8 +43,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_style.py 310 2007-07-22 02:29:01Z CodyPrecord $"
-__revision__ = "$Revision: 310 $"
+__svnid__ = "$Id: ed_style.py 387 2007-08-28 05:15:47Z CodyPrecord $"
+__revision__ = "$Revision: 387 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -522,10 +522,16 @@ class StyleMgr(object):
 
         """
         if self.HasNamedStyle(name):
-            if u"%" in unicode(self.styles[name]):
-                return unicode(self.styles[name]) % self.fonts
-            else:
-                return unicode(self.styles[name])
+            try:
+                if u"%" in unicode(self.styles[name]):
+                    style = unicode(self.styles[name]) % self.fonts
+                else:
+                    style = unicode(self.styles[name])
+            except KeyError, msg:
+                self.LOG("[styles][err] Bad Format Value %s in def of %s" % \
+                         (str(msg), name))
+                style = wx.EmptyString
+            return style
         else:
             return wx.EmptyString
 
