@@ -81,8 +81,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: plugin.py 267 2007-07-07 10:38:04Z CodyPrecord $"
-__revision__ = "$Revision: 267 $"
+__cvsid__ = "$Id: plugin.py 319 2007-07-23 13:26:58Z CodyPrecord $"
+__revision__ = "$Revision: 319 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -341,7 +341,7 @@ class PluginManager(object):
                 self.LOG("[pluginmgr][err] %s Not Registered" % cls.__name__)
             try:
                 plugin = cls(self)
-            except TypeError, msg:
+            except (AttributeError, TypeError), msg:
                 self.LOG("[pluginmgr][err] Unable in initialize plugin")
                 self.LOG("[pluginmgr][err] %s" % str(msg))
         return plugin
