@@ -31,8 +31,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 322 2007-07-25 09:37:15Z CodyPrecord $"
-__revision__ = "$Revision: 322 $"
+__svnid__ = "$Id: prefdlg.py 367 2007-08-20 07:53:06Z CodyPrecord $"
+__revision__ = "$Revision: 367 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -308,12 +308,17 @@ class GeneralPanel(PrefPanelBase):
                             default=Profile_Get('PRINT_MODE'))
         psizer = wx.BoxSizer(wx.HORIZONTAL)
         psizer.AddMany([(pmode_lbl, 0), ((5, 5), 0), (pmode_ch, 0)])
-        splash_cb = wx.CheckBox(self, ed_glob.ID_APP_SPLASH, 
-                                _("Show Splash Screen"))
-        splash_cb.SetValue(Profile_Get('APPSPLASH'))
         reporter_cb = wx.CheckBox(self, ed_glob.ID_REPORTER, 
                                   _("Disable Error Reporter"))
         reporter_cb.SetValue(not Profile_Get('REPORTER'))
+        session_cb = wx.CheckBox(self, ed_glob.ID_SESSION, 
+                                 _("Load Last Session"))
+        session_cb.SetValue(Profile_Get('SAVE_SESSION'))
+        tt = wx.ToolTip(_("Load files from last session on startup"))
+        session_cb.SetToolTip(tt)
+        splash_cb = wx.CheckBox(self, ed_glob.ID_APP_SPLASH, 
+                                _("Show Splash Screen"))
+        splash_cb.SetValue(Profile_Get('APPSPLASH'))
 
         # File settings
         file_lbl = wx.StaticText(self, label=_("File Settings") + u": ")
@@ -345,13 +350,14 @@ class GeneralPanel(PrefPanelBase):
                        (start_lbl, (1, 1)),
                        (msizer, (1, 2), (1, 2)),
                        (psizer, (2, 2), (1, 2)),
-                       (splash_cb, (3, 2), (1, 2)),
-                       (reporter_cb, (4, 2), (1, 2))])
-        sizer.AddMany([(file_lbl, (6, 1)),
-                       (fhsizer, (6, 2), (1, 2)), (pos_cb, (7, 2), (1, 3)),
-                       (chkmod_cb, (8, 2), (1, 2))])
-        sizer.AddMany([(locale, (10, 1)),
-                       (lsizer, (10, 2), (1, 3))])
+                       (reporter_cb, (3, 2), (1, 2)),
+                       (session_cb, (4, 2), (1, 2)),
+                       (splash_cb, (5, 2), (1, 2))])
+        sizer.AddMany([(file_lbl, (7, 1)),
+                       (fhsizer, (7, 2), (1, 2)), (pos_cb, (8, 2), (1, 3)),
+                       (chkmod_cb, (9, 2), (1, 2))])
+        sizer.AddMany([(locale, (11, 1)),
+                       (lsizer, (11, 2), (1, 3))])
         self.SetSizer(sizer)
 
     def OnCheck(self, evt):
@@ -363,7 +369,7 @@ class GeneralPanel(PrefPanelBase):
         e_id = evt.GetId()
         e_obj = evt.GetEventObject()
         if e_id in [ed_glob.ID_APP_SPLASH, ed_glob.ID_PREF_SPOS,
-                    ed_glob.ID_PREF_CHKMOD]:
+                    ed_glob.ID_PREF_CHKMOD, ed_glob.ID_SESSION]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
         elif e_id == ed_glob.ID_REPORTER:
             Profile_Set(ed_glob.ID_2_PROF[e_id], not e_obj.GetValue())
@@ -512,6 +518,8 @@ class DocGenPanel(wx.Panel):
         e_id = evt.GetId()
         if e_id in [self.ID_FONT_PICKER, self.ID_FONT_PICKER2]:
             font = evt.GetValue()
+            if font == wx.EmptyString:
+                return
             if e_id == self.ID_FONT_PICKER:
                 Profile_Set('FONT1', font, 'font')
             else:
@@ -536,7 +544,7 @@ class DocGenPanel(wx.Panel):
                     ed_glob.ID_EOL_MODE, ed_glob.ID_PREF_AALIAS,
                     ed_glob.ID_SHOW_EOL, ed_glob.ID_SHOW_LN,
                     ed_glob.ID_SHOW_WS, ed_glob.ID_WORD_WRAP,
-                     ed_glob.ID_PREF_AALIAS]:
+                    ed_glob.ID_PREF_AALIAS]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
             mainw = wx.GetApp().GetMainWindow()
             if mainw is not None:
@@ -593,6 +601,8 @@ class DocCodePanel(wx.Panel):
         comp_cb.SetValue(Profile_Get('AUTO_COMP'))
         ai_cb = wx.CheckBox(self, ed_glob.ID_AUTOINDENT, _("Auto-Indent"))
         ai_cb.SetValue(Profile_Get('AUTO_INDENT'))
+        vi_cb = wx.CheckBox(self, ed_glob.ID_VI_MODE, _("Enable Vi Emulation"))
+        vi_cb.SetValue(Profile_Get('VI_EMU'))
 
         # Layout the controls
         sizer = wx.GridBagSizer(5, 5)
@@ -603,7 +613,7 @@ class DocCodePanel(wx.Panel):
                        (wx.StaticText(self, label=_("Column") + u": "), (3, 3)),
                        (edge_sl, (3, 4), (2, 2), wx.EXPAND), (ind_cb, (4, 2))])
         sizer.Add(wx.StaticText(self, label=_("Input Helpers") + u": "), (6, 1))
-        sizer.AddMany([(comp_cb, (6, 2)), (ai_cb, (7, 2))])
+        sizer.AddMany([(comp_cb, (6, 2)), (ai_cb, (7, 2)), (vi_cb, (8, 2))])
         self.SetSizer(sizer)
 
     def OnCheck(self, evt):
@@ -618,7 +628,7 @@ class DocCodePanel(wx.Panel):
         if e_id in [ed_glob.ID_BRACKETHL, ed_glob.ID_SHOW_EDGE,
                     ed_glob.ID_INDENT_GUIDES, ed_glob.ID_FOLDING,
                     ed_glob.ID_AUTOCOMP, ed_glob.ID_AUTOINDENT,
-                    ed_glob.ID_PREF_EDGE]:
+                    ed_glob.ID_PREF_EDGE, ed_glob.ID_VI_MODE]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
             mainw = wx.GetApp().GetMainWindow()
             if mainw is not None:
@@ -1255,6 +1265,8 @@ class PyFontPicker(wx.Panel):
 
         """
         font = evt.GetFont()
+        if font.IsNull():
+            return
         self._font = font
         self._text.Clear()
         self._text.SetFont(self._font)
