@@ -38,8 +38,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 322 2007-07-25 09:37:15Z CodyPrecord $"
-__revision__ = "$Revision: 322 $"
+__svnid__ = "$Id: profiler.py 388 2007-08-29 15:27:46Z CodyPrecord $"
+__revision__ = "$Revision: 388 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -67,6 +67,7 @@ _DEFAULTS = {
            'EDGE'       : 80,               # Edge guide column
            'EOL'        : 'Unix (\\n)',     # EOL mode
            'FHIST_LVL'  : 5,                # Filehistory length (9 is max)
+           'FFILTER'    : 0,                # Last file filter used
            'GUIDES'     : True,             # Use Indentation guides
            'ICONS'      : 'Nuovo',          # Icon Theme
            'ICON_SZ'    : (24, 24),         # Toolbar Icon Size
@@ -76,20 +77,22 @@ _DEFAULTS = {
            'PRINT_MODE' : 'BLACK/WHITE',    # Printer rendering mode
            'REPORTER'   : True,             # Error Reporter is Active
            'SAVE_POS'   : True,             # Remember Carat positions
+           'SAVE_SESSION' : False,          # Load previous session on startup
+           'SET_WPOS'   : True,             # Remember window position
+           'SET_WSIZE'  : True,             # Remember mainwindow size on exit
            'SHOW_EDGE'  : True,             # Show Edge Guide
            'SHOW_EOL'   : False,            # Show EOL markers
            'SHOW_LN'    : True,             # Show Line Numbers
+           'SHOW_WS'    : False,            # Show whitespace markers
            'SYNTAX'     : True,             # Use Syntax Highlighting
            'SYNTHEME'   : 'Default',        # Syntax Highlight color scheme
            'TABWIDTH'   : 8,                # Tab width
            'THEME'      : 'DEFAULT',        # For future use
            'TOOLBAR'    : True,             # Show Toolbar
            'USETABS'    : True,             # Use tabs instead of spaces
-           'SHOW_WS'    : False,            # Show whitespace markers
+           'VI_EMU'     : False,            # Use Vi emulation mode 
            'WRAP'       : True,             # Use Wordwrap
-           'SET_WSIZE'  : True,             # Remember mainwindow size on exit
-           'WSIZE'      : (700, 450),       # Mainwindow size
-           'SET_WPOS'   : True              # Remember window position
+           'WSIZE'      : (700, 450)        # Mainwindow size
 }
 
 #--------------------------------------------------------------------------#
@@ -185,9 +188,10 @@ class Profile(dict):
             self.Set('MYPROFILE', path)
             return False
 
-        if len(self) < len(_DEFAULTS):
-            self.update(_DEFAULTS)
-            return False
+        # Update profile to any keys that are missing
+        for key in _DEFAULTS:
+            if key not in self:
+                self.Set(key, _DEFAULTS[key])
         return True
 
     def LoadDefaults(self):
@@ -292,7 +296,7 @@ def _ToObject(index, val, fmt):
                 rval = _DEFAULTS.get(index, False)
         elif tmp == u'size_tuple':
             if len(val) == 2 and \
-               all([isinstance(val[0], int), isinstance(val[1], int)]):
+               isinstance(val[0], int) and isinstance(val[1], int):
                 rval = val
             else:
                 rval = _DEFAULTS.get(index, wx.DefaultSize)
