@@ -38,13 +38,14 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: util.py 311 2007-07-22 03:30:22Z CodyPrecord $"
-__revision__ = "$Revision: 311 $"
+__svnid__ = "$Id: util.py 353 2007-08-17 10:27:29Z CodyPrecord $"
+__revision__ = "$Revision: 353 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
 import sys
+import shutil
 import stat
 import codecs
 import mimetypes
@@ -493,14 +494,8 @@ def CreateConfigDir():
             MakeConfigDir(cfg)
 
     #---- Copy Default Config Files ----#
-    if os.sys.platform == 'win32':
-        os.system(u"copy " + u"\"" + config_file + u"\" \"" + dest_file + u"\"")
-        os.system(u"copy " + u"\"" + loader + u"\" \"" + profile_dir + 
-                  GetPathChar() + u".loader2\"")
-    else:
-        os.system(u"cp " + config_file + " " + dest_file)
-        os.system(u"cp " + loader + " " + profile_dir + 
-                  pchar + u".loader2")
+    shutil.copyfile(config_file, dest_file)
+    shutil.copyfile(loader, profile_dir + pchar + u".loader2")
 
     import profiler
     profiler.Profile().Load(dest_file)
@@ -632,6 +627,13 @@ def GetResourceFiles(resource, trim=True, get_all=False):
         rec_list.sort()
         return list(set(rec_list))
 
+def Log(msg):
+    """Push the message to the apps log
+    @param msg: message string to log
+
+    """
+    wx.GetApp().GetLog()(msg)
+
 # GUI helper functions
 def AdjustColour(color, percent, alpha=wx.ALPHA_OPAQUE):
     """ Brighten/Darken input colour by percent and adjust alpha
